aboutsummaryrefslogtreecommitdiffstats
path: root/asn1/h248/packet-h248-template.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2007-01-02 09:20:27 +0000
committerGuy Harris <guy@alum.mit.edu>2007-01-02 09:20:27 +0000
commit04ca66dfb10095ac62abe24e7b16aafde3b01603 (patch)
tree1b99de605ea90de8ee78281ca922220e1f7c4148 /asn1/h248/packet-h248-template.c
parent44c0624bd9f0a4a69777cfdeab8d1b05690c6f36 (diff)
Ehtereal[sic] -> Wireshark. :-)
Give a little more detail in the comment in the H.248 dissector about "MEGACO" vs. "H.248". svn path=/trunk/; revision=20262
Diffstat (limited to 'asn1/h248/packet-h248-template.c')
-rw-r--r--asn1/h248/packet-h248-template.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/asn1/h248/packet-h248-template.c b/asn1/h248/packet-h248-template.c
index 48ce925404..05cfb8d82d 100644
--- a/asn1/h248/packet-h248-template.c
+++ b/asn1/h248/packet-h248-template.c
@@ -1782,9 +1782,10 @@ dissect_h248(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
curr_info.stat = NULL;
curr_info.par = NULL;
- /* Check if it is actually a text based h248 encoding, which we call
- megaco in ehtereal.
- */
+ /* Check if it is actually a text-based H.248 encoding, which we
+ dissect with the "megaco" dissector in Wireshark. (Both
+ encodings are MEGACO (RFC 3015) and both are H.248.)
+ */
if(tvb_length(tvb)>=6){
if(!tvb_strneql(tvb, 0, "MEGACO", 6)){
static dissector_handle_t megaco_handle=NULL;